params = [
{
'validationcase':'Abdilla2015endurance',
'wingtype': 'rotary',
'rotorquantity': 4.0,
'endurancemax': 12.0,
'rangemax': 50.0,
'takeoffweight': 1.81,
'batterycapacity': 2200.0,
'batteryvoltage': 11.1,
'batterytype': 'LiPo',
'batterymass': 0.191,
'payload': 0.0,
'rotordiameter': 0.2
},
{
'validationcase':'Chang2016',
'wingtype': 'rotary',
'rotorquantity': 4,
'takeoffweight': 1.3,
'batterytype': 'LiPo',
'batteryvoltage': 11.1,
'batterymass': 0.262,
'props': '10x4.7',
'endurancemax': 15,
'payloadmax': 0.4,
'batterycapacity': 5500,
'payload': 0.095,
'rotordiameter': 0.254
},
{
'validationcase': 'DiFranco2016',
'wingtype': 'rotary',
'rotorquantity': 4,
'takeoffweight': 1.3,
'batterytype': 'LiPo',
'batteryvoltage': 11.1,
'batterymass': 0.262,
'props': '10x4.7',
'endurancemaxhover': 16,
'payloadmax': 0.4,
'batterycapacity': 5500,
'payload': 0.0,
'rotordiameter': 0.254,
'batterycells': 3,
'length': 0.280,
'width': 0.140,
'height': 0.100,
'waterproof': 'no'
},
{
'validationcase':'Dorling2017_3S',
'wingtype': 'rotary',
'rotorquantity': 6,
'takeoffweight': 1.5,
'batterytype': 'LiPo',
'batteryvoltage': 14.8,
'batterymass': 0.5,
'props': '10x4.7',
'endurancemax': 15
},
{
'validationcase':'Dorling2017_4S',
'wingtype': 'rotary',
'rotorquantity': 6,
'takeoffweight': 1.5,
'batterytype': 'LiPo',
'batteryvoltage': 14.8,
'batterymass': 0.5,
'props': '10x4.7'
},
{
'validationcase':'FireFLY6Pro',
'wingtype': 'fixed',
'span': 1.524,
'takeoffweight': 4.5,
'endurancemax': 59,
'max_payload': 0.7,
'cruise_speed': 18,
'VTOL': 'yes',
'batterytype': 'LiHV'
},
{
'validationcase':'FreeflyAlta8',
'wingtype': 'rotary',
'rotorquantity': 8,
'diagonal': 1.325,
'batterycells': 6,
'batteryvoltage': 22.2,
'batterycapacity': 10000,
'batterytype': 'LiPo',
'numbatteries': 2,
'numbatteriesconnection': 'parallel',
'max_takeoffweight': 18.1,
'takeoffweight': 6.2,
'max_payload': 9.1,
'specific_power': 145,
'props': '18x6_Folding',
'motor_max_power_continuous': 350,
'motor_max_power_peak': 950,
'temperaturemin': -20,
'temperaturemax': 45,
'thrust_ratio_at_max_takeoffweight': '1.85:1',
'rotordiameter': 0.4572,
'payload': 0.0
},
{
'validationcase':'Ostler2009',
'wingtype': 'fixed',
'wingarea': 0.321,
'wingspan': 1.06,
'rotorquantity': 1,
'batteryvoltage': 11.1,
'batterycapacity': 1500,
'batterytype': 'LiPo',
'numbatteries': 2,
'numbatteriesconnection': 'parallel',
'takeoffweight': 0.95,
'props': '7x4',
'rotordiameter': 0.1778,
'payload': 0.0,
'motorio': 0.65
},
{
'validationcase':'Stolaroff2018',
'wingtype': 'rotary',
'rotorquantity': 4,
'takeoffweight': 1.3,
'batterytype': 'LiPo',
'batteryvoltage': 11.1,
'batterymass': 0.262,
'props': '10x4.7',
'endurancemaxhover': 16,
'payloadmax': 0.4,
'batterycapacity': 5500,
'payload': 0.0,
'rotordiameter': 0.254,
'batterycells': 3,
'length': 0.280,
'width': 0.140,
'height': 0.100,
'waterproof': 'no'
}
]


params = [
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 85.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'alpha',
'title': 'Stolaroff',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.0,
'xend': 15.0,
'xnumber': 10,
'validation': False,
'validationcase': 'Stolaroff2018',
'batterytechnology': 'current'
},
{
'validation': False,
'validationcase': 'Ostler2009',
'drone': True,
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 89.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'power',
'title': 'Ostler2009',
'simulationtype': 'simple',
'xbegin': 0.0,
'xend': 30.0,
'xnumber': 20,
'batterytechnology': 'current'
},
{
'drone': True,
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 89.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'endurance',
'title': 'FreeFLY_Alta8',
'simulationtype': 'simple',
'xbegin': 0.0,
'xend': 10.0,
'xnumber': 100,
'validation': False,
'validationcase': 'FreeFLYAlta8',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'endurance',
'title': 'FreeFLY_Alta8',
'simulationtype': 'simple',
'xbegin': 0.0,
'xend': 1.0,
'xnumber': 20,
'validation': False,
'validationcase': 'FireFLY6Pro',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 90.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'power',
'title': 'First_test',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.5,
'xend': 1.5,
'xnumber': 10,
'validation': False,
'validationcase': 'Dorling2017_3S',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 90.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'power',
'title': 'First_test',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.5,
'xend': 1.5,
'xnumber': 10,
'validation': False,
'validationcase': 'Dorling2017_4S',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'power',
'title': 'DiFranco',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.0,
'xend': 16.0,
'xnumber': 20,
'validation': False,
'validationcase': 'DiFranco2016',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'power',
'title': 'Stolaroff',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.0,
'xend': 16.0,
'xnumber': 20,
'validation': False,
'validationcase': 'Chang2016',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 90.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'endurance',
'title': 'Abdilla 2015 Endurance vs Payload Validation Test',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.4,
'xend': 0.55,
'xnumber': 20,
'validation': False,
'validationcase': 'Abdilla2015endurance',
'batterytechnology': 'current'
}
]